package com.meas.system.service;

import com.meas.system.domain.MeasEngineModel;

import java.util.List;
import java.util.Map;

/**
 * 发动机型号Service接口
 *
 * @author km
 * @date 2024-06-13
 */
public interface IMeasEngineModelService {
    /**
     * 查询发动机型号
     *
     * @param id 发动机型号主键
     * @return 发动机型号
     */
    public MeasEngineModel selectMeasEngineModelById(Long id);

    /**
     * 查询发动机型号列表
     *
     * @param measEngineModel 发动机型号
     * @return 发动机型号集合
     */
    public List<MeasEngineModel> selectMeasEngineModelList(MeasEngineModel measEngineModel);

    /**
     * 新增发动机型号
     *
     * @param measEngineModel 发动机型号
     * @return 结果
     */
    public int insertMeasEngineModel(MeasEngineModel measEngineModel);

    /**
     * 修改发动机型号
     *
     * @param measEngineModel 发动机型号
     * @return 结果
     */
    public int updateMeasEngineModel(MeasEngineModel measEngineModel);

    /**
     * 批量删除发动机型号
     *
     * @param ids 需要删除的发动机型号主键集合
     * @return 结果
     */
    public int deleteMeasEngineModelByIds(Long[] ids);

    /**
     * 删除发动机型号信息
     *
     * @param id 发动机型号主键
     * @return 结果
     */
    public int deleteMeasEngineModelById(Long id);

    List<Map> getOption();
}
